Documentation
¶
Index ¶
Constants ¶
const Version = "0.0.1"
Version indicates package version
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Recordset ¶
type Recordset struct {
Type RecordsetType
Name string
PrimaryKey []Field // Primary keys by table name
}
Recordset hold recordset settings
type RecordsetType ¶
type RecordsetType = int
RecordsetType defines type of a database recordset
const ( // Table identifies a table in a database Table RecordsetType = iota // View identifies a view in a database View // StoredProcedure identifies a stored procedure in a database StoredProcedure )
Source Files
¶
Click to show internal directories.
Click to hide internal directories.